summaryrefslogtreecommitdiff
path: root/src/passes/StackIR.cpp
diff options
context:
space:
mode:
authorHeejin Ahn <aheejin@gmail.com>2019-05-21 13:25:14 -0700
committerGitHub <noreply@github.com>2019-05-21 13:25:14 -0700
commit1a3c1a58cc7e97a846f612baf7f74a370980458f (patch)
treecbe62ea58b2c0dd6d98225265419fea0b829aeab /src/passes/StackIR.cpp
parentd78be9ac6c02910bbf8ac71118e68adff4fdc570 (diff)
downloadbinaryen-1a3c1a58cc7e97a846f612baf7f74a370980458f.tar.gz
binaryen-1a3c1a58cc7e97a846f612baf7f74a370980458f.tar.bz2
binaryen-1a3c1a58cc7e97a846f612baf7f74a370980458f.zip
Reflect instruction renaming in code (#2128)
- Reflected new renamed instruction names in code and tests: - `get_local` -> `local.get` - `set_local` -> `local.set` - `tee_local` -> `local.tee` - `get_global` -> `global.get` - `set_global` -> `global.set` - `current_memory` -> `memory.size` - `grow_memory` -> `memory.grow` - Removed APIs related to old instruction names in Binaryen.js and added APIs with new names if they are missing. - Renamed `typedef SortedVector LocalSet` to `SetsOfLocals` to prevent name clashes. - Resolved several TODO renaming items in wasm-binary.h: - `TableSwitch` -> `BrTable` - `I32ConvertI64` -> `I32WrapI64` - `I64STruncI32` -> `I64SExtendI32` - `I64UTruncI32` -> `I64UExtendI32` - `F32ConvertF64` -> `F32DemoteI64` - `F64ConvertF32` -> `F64PromoteF32` - Renamed `BinaryenGetFeatures` and `BinaryenSetFeatures` to `BinaryenModuleGetFeatures` and `BinaryenModuleSetFeatures` for consistency.
Diffstat (limited to 'src/passes/StackIR.cpp')
-rw-r--r--src/passes/StackIR.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/passes/StackIR.cpp b/src/passes/StackIR.cpp
index 1f182dbc3..d834655b9 100644
--- a/src/passes/StackIR.cpp
+++ b/src/passes/StackIR.cpp
@@ -132,7 +132,7 @@ private:
localGraph.computeInfluences();
// We maintain a stack of relevant values. This contains:
// * a null for each actual value that the value stack would have
// * an index of each SetLocal that *could* be on the value
// stack at that location.
const Index null = -1;
std::vector<Index> values;
@@ -188,7 +188,7 @@ private:
// This is something we should handle, look into it.
if (isConcreteType(inst->type)) {
bool optimized = false;
- if (auto* get = inst->origin->dynCast<GetLocal>()) {
+ if (auto* get = inst->origin->dynCast<LocalGet>()) {
// This is a potential optimization opportunity! See if we
// can reach the set.
if (values.size() > 0) {
@@ -199,7 +199,7 @@ private:
if (index == null) {
break;
}
- auto* set = insts[index]->origin->cast<SetLocal>();
+ auto* set = insts[index]->origin->cast<LocalSet>();
if (set->index == get->index) {
// This might be a proper set-get pair, where the set is
// used by this get and nothing else, check that.
@@ -238,7 +238,7 @@ private:
// This is an actual regular value on the value stack.
values.push_back(null);
}
- } else if (inst->origin->is<SetLocal>() && inst->type == none) {
+ } else if (inst->origin->is<LocalSet>() && inst->type == none) {
// This set is potentially optimizable later, add to stack.
values.push_back(i);
}
@@ -132,7 +132,7 @@ private:
// We maintain a stack of relevant values. This contains:
// * a null for each actual value that the value stack would have
- // * an index of each SetLocal that *could* be on the value
+ // * an index of each LocalSet that *could* be on the value
// stack at that location.
const Index null = -1;